/* This is the main header file for FPGE */
#include "allegro.h"

#define BYTE unsigned char
#define WORD short

#define MAX_ICONS 500  //most icons that can be loaded into address
#define MAX_TILES 256  //maximum number of map tile icons
#define MAX_UICONS 300 //maximum number of unit icons
#define MAX_UNITS 500  //maimum number of units in equipment file
#define MAX_FLAGS 50   //actually 48
#define BK_COLOR 0     //transparent shp color
#define HEADER_SIZE 24 //size of shp header


#define MAX_VICTORY_HEXES 20
#define MAX_DEPLOY_HEXES  80
#define MAX_CORE_UNITS    80
#define MAX_ALLIED_UNITS 200
#define MAX_AUX_UNITS    120
#define MAX_NAMES        1200
#define MAX_MAP_X 71
#define MAX_MAP_Y 54
#define TILES_WIDE 12
#define TILES_HIGH 8
#define TILE_HEIGHT 50
#define TILE_WIDTH 45
#define MAP_X_ADDR 101
#define MAP_Y_ADDR 103

/*  -------------------- Here is the Main Dialog ----------------------- */
/* ------ this section has defines for the main dialog ------------------- */
#define TOP_LINE_Y 2
#define LINE_1_Y   28
#define LINE_2_Y   54

#define VSLIDE_W 23
#define VSLIDE_H 200
#define VSLIDE_X 560
#define VSLIDE_Y 200

#define HSLIDE_W 200
#define HSLIDE_H 23
#define HSLIDE_X 200
#define HSLIDE_Y LINE_1_Y

#define MAP_H 426
#define MAP_W 555
#define MAIN_BUTTON_X 590
#define BUTTON_H 15
#define BUTTON_W 45
#define EXIT_Y 470
#define BUTTON_SIZE 20


#define FG_COLOR 41
#define BG_COLOR 54
#define SCREEN_COLOR 8
#define MAP_COLOR 149
#define SLIDE_BG_COLOR 38
#define SLIDE_FG_COLOR 33
#define VIC_HEX_COLOR 4

/* ------ this section holds the functions prototypes for the main dialog */
BITMAP *map_bmp;
BITMAP *left_arrow_bmp;
BITMAP *right_arrow_bmp;
BITMAP *up_arrow_bmp;
BITMAP *down_arrow_bmp;
BITMAP *vic_hex_bmp;

void draw_map() ;

int d_btn_proc(int,DIALOG *,int); //our function to make buttons act like
                                  //radio buttons
int d_mapbmp_proc(int,DIALOG *,int);

int d_arrow_proc(int,DIALOG *,int);

int d_hslide_proc(int,DIALOG *,int);
int d_vslide_proc(int,DIALOG *,int);

int d_GndAir_proc(int,DIALOG *,int);
int d_mapinfo_proc(int,DIALOG *,int);
int d_mapstatus_proc(int,DIALOG *,int);
int d_coreRB_proc(int,DIALOG *,int);

char *add_countries(int idx,int *list_size); //unit and scen
void setup_terrain_info();

//we won't treat equip as a structure but will use offsets into the records
#define EQUIP_REC_SIZE 50

#define NAME   0
#define CLASS 20
#define SA    21
#define HA    22
#define AA    23
#define NA    24
#define GD    25
#define AD    26
#define CD    27
#define AAF   29   //1 for tac bombers who can attack
#define INI   31
#define RNG   32
#define SPT   33
#define GAF   34    //the ground=0 air=1 flag
#define MOV_TYPE 35
#define MOV   36
#define FUEL  37
#define AMMO  38
#define COST  41
#define BMP   42
#define MON   46
#define YR    47
#define LAST_YEAR 48

//similarly we will use an array to store the scenario
#define MAX_SCN_SIZE 5000
// These are offsets or starting addresses into the scenario file
#define ORIENTATION 12 //2bytes
#define AXIS_STANCE 14
#define ALLIED_STANCE 15
#define STORM_FRONT 16
#define SCEN_LOCALE 17
#define CORE_UNITS_LIMIT 18
#define AUX_UNITS_LIMIT 19
#define ALLIED_UNITS_LIMIT  20
#define TURNS 21
#define DAY   22
#define MONTH 23
#define YEAR  24
#define TURNS_PER_DAY 25
#define DAYS_PER_TURN 26
#define AI_AXIS_BUCKET 27 //2 bytes
#define AI_ALLIED_BUCKET 29 //2 bytes
#define AI_AXIS_INTERVAL 31
#define AI_ALLIED_INTERVAL 32
#define CORE_UNITS    33
#define ALLIED_UNITS  34
#define AUX_UNITS     35
#define VIC_HEXES     37    //up to 20 terminated with -1
#define DEPLOY_TABLE  117
#define DEPLOY_TO_UNITS 0x87


/* ---------- Here we define structures ----------------------------------*/
struct shp_header
{
  int lines;     // last starting at 0 ie lines-1
  int width;
  int centerx;
  int centery;
  long xstart;
  long ystart;
  long xend;
  long yend;
};

struct MAP {
  short utr;
  unsigned char own;
  unsigned char vic;
  unsigned char rc;
  unsigned char side;
  unsigned char deploy;
  short tile;
  short gln;
  short auidx; //index of air unit in all_units no unit=-1
  short guidx; //index of ground unit in all_units  no unit=-1
};

struct VICTORY_HEXES{
  WORD x,y;
  BYTE own;
};

struct DEPLOY_HEXES{
  WORD x,y;
};


enum UTYPES {core,aux,allied};
//the unit as stored in the scn file
struct UNIT {
  WORD unum;
  WORD orgtnum;       //organic
  BYTE country;
  WORD auxtnum;      //sea/air transport
  WORD x;
  WORD y;
  BYTE str,entrench,exp;
  enum UTYPES uflag; //what type of unit
};

// called dialogs
extern DIALOG ud[];
extern DIALOG sd[];
extern DIALOG td[];

//-------------------- global variable declarations --------
extern struct shp_header header;
extern struct MAP  map[MAX_MAP_X][MAX_MAP_Y]; //main map storage
extern unsigned char equip[MAX_UNITS][EQUIP_REC_SIZE];
extern BYTE scn_buffer[MAX_SCN_SIZE];
extern int scn_size; //bytes we actually read
extern int show_air; //toggle depending on whether air or gound selected
extern char unit_names[][]; //unit type names infantry tank etc.
extern char country_names[25][16];
extern enum EDIT_FUNCTION {none,str,exp,place,
                           ent,vic,own,ter,tile,deploy,neutral} edit_op;
extern int unit_type_selected; //picked in the ud dialog
extern int unum_selected,tnum_selected;
extern int cnum_selected; //the current country
extern int anum_selected; //aux transport
extern int total_units;  //in on map
extern int total_equip; //units in panzequp
extern unsigned char equip[MAX_UNITS][EQUIP_REC_SIZE];
extern char uselected[16];
extern char tselected[16];
extern char cselected[16];
extern char aselected[16];
extern map_mouse_x,map_mouse_y; // coordinates on map
extern int ustr_selected;
extern int uent_selected;
extern int uexp_selected;
extern int scn_number;
extern struct VICTORY_HEXES victory_hexes[];

// offsets in s4_buffer
#define AXIS_PRESTIGE   0
#define ALLIED_PRESTIGE 2
#define AXIS_AIR_NUMBER 4
#define ALLIED_AIR_NUMBER 5
#define AXIS_SEA_NUMBER 6
#define ALLIED_SEA_NUMBER 7
#define AXIS_AIR_TYPE 8
#define ALLIED_AIR_TYPE 10
#define AXIS_SEA_TYPE 12
#define ALLIED_SEA_TYPE 14

extern BYTE s4_buffer[16];

extern char tdTTStr[8];
extern char tdRDStr[8];
extern char tdTNStr[8];
extern char tdGLNStr[8];
extern char tdSDStr[8];

extern char MonthStr[8];
extern char YearStr[8];
